@@ -66,7 +66,8 @@ EngineSettings::EngineSettings(QWidget* parent, Qt::WindowFlags f) : QWidget(par
 	//add saved engines
 	int row = 0;
 	for ( const QString& s : Settings::engineConfigurations() ) {
-		addClicked();
+		addInitialize();
+
 		EngineConfiguration c = EngineConfiguration ( s );
 		ui->tableWidget->setItem ( row, NameColumn, new QTableWidgetItem ( c.name ) );
 		ui->tableWidget->setItem ( row, CommandColumn, new QTableWidgetItem ( c.commandLine ) );
@@ -90,9 +91,9 @@ EngineSettings::~EngineSettings() {
 
 void EngineSettings::checkInstalled(int row, const QString& name) {
 	const bool exists = !QStandardPaths::findExecutable(name).isEmpty();
-	const char* iconName = exists ? "dialog-ok" : "dialog-error";
+	const QString iconName = exists ? QStringLiteral("dialog-ok") : QStringLiteral("dialog-error");
 	QLabel* label = new QLabel(this);
-	label->setPixmap ( QIcon::fromTheme(QLatin1String(iconName)).pixmap(32, 32) );
+	label->setPixmap ( QIcon::fromTheme(iconName).pixmap(32, 32) );
 	ui->tableWidget->setCellWidget(row, InstalledColumn, label );
 }
 
@@ -102,13 +103,22 @@ void EngineSettings::tableItemChanged(QTableWidgetItem* item) {
 		checkInstalled(item->row(), item->text());
 }
 
-void EngineSettings::addClicked() {
-	int n = ui->tableWidget->rowCount();
+void EngineSettings::addInitialize() {
+	const int n = ui->tableWidget->rowCount();
 	ui->tableWidget->insertRow ( n );
+
 	KComboBox* box = new KComboBox ( this );
-	box->insertItems(0, {i18nc("Protocol name", "XBoard"), i18nc("Protocol name", "UCI")});
+	box->insertItems(0, {i18nc("Protocol name", "XBoard"),
+		i18nc("Protocol name", "UCI")});
 	ui->tableWidget->setCellWidget ( n, ProtocolColumn, box );
-	ui->tableWidget->edit ( ui->tableWidget->model()->index ( n, NameColumn ) );
+}
+
+void EngineSettings::addClicked() {
+	addInitialize();
+
+	const int rowIndex = ui->tableWidget->rowCount() - 1;
+	ui->tableWidget->edit(ui->tableWidget->model()->
+		index(rowIndex, NameColumn));
 }
 
 void EngineSettings::removeClicked() {
